@@ -3,11 +3,11 @@
 #' This function implements the exact maximum likelihood estimator for the
 #' instantaneous sampling rate from Solow and Smith (1997, Paleobiology),
 #' which is based on the relationship between the number of collections for a
-#' set of tax and their durations (known precisely in continuous time).
+#' set of taxa and their durations (known precisely in continuous time).
 
 #' @details 
-#' Given a dataset of taxa with a vector N, representing the number of
-#' collections for each taxon, and a vector D, giving the precise duration
+#' Given a dataset of taxa with a vector \eqn{N}, representing the number of
+#' collections for each taxon, and a vector \eqn{D}, giving the precise duration
 #' for each taxon, we can use the following maximum likelihood estimator from
 #' Solow and Smith (1997) to obtain the instantaneous sampling rate:
 #'
@@ -25,19 +25,19 @@
 #' and each element of the list being a numerical vector with the length equal
 #' to the number of collections for each taxon, and each value equal to the
 #' precise date of that fossil's time of collection. These dates do not need
-#' to be ordered. If not supplied, the elements durations and nCollections must
+#' to be ordered. If not supplied, the elements \code{durations} and \code{nCollections} must
 #' be supplied.
 
 #' @param durations A vector of precise durations in continuous time, with the
-#' length equal to the number of taxa. If not suppliedthis is calculated from
-#' SampOcc, which must be supplied.
+#' length equal to the number of taxa. If not supplied, this is calculated from
+#' \code{SampOcc}, which must be supplied.
 
 #' @param nCollections A vector of integers representing the number of
 #' collections for each taxon in the input durations. If not supplied
-#' this is calculated from SampOcc, which must be supplied.
+#' this is calculated from \code{SampOcc}, which must be supplied.
 
 #' @return
-#' Returns the instantaneous sampling (in lineage*time-units) as a
+#' Returns the instantaneous sampling (in per lineage*time-units) as a
 #' single numerical value. Note that this is the instantaneous sampling
 #' rate and not the probability of sampling a taxon per interval.
 
@@ -82,11 +82,44 @@ horizonSampRate<-function(sampOcc=NULL,durations=NULL,nCollections=NULL){
 	#input is a list, with each element a taxon, consisting of n sampling occurrences
 		#just like sampleRanges(data,ranges.only=FALSE)
 	if(is.null(durations) & is.null(nCollections)){
+		if(is.null(sampOcc)){
+			stop("No input data supplied!")}
 		if(!is.list(sampOcc)){
-			stop("sampOcc isn't a list of species occurrences")}
+			stop("sampOcc is supplied but in't a list of species occurrences")}
 		sampOcc<-sampOcc[!is.na(sampOcc)]
 		nCollections<-sapply(sampOcc,length)
 		durations<-sapply(sampOcc,max)-sapply(sampOcc,min)
+		names(durations)<-names(nCollections)<-names(sampOcc)
+		}
+	#check lengths
+	if(length(durations)!=length(nCollections)){
+		stop("durations and nCollections are not the same length")
+		}
+	#check names
+	if(is.null(names(durations)) | is.null(names(nCollections))){
+		message("Input data lacks names, assuming ")
+	}else{
+		# check that names are the same, if not re-sort and re-check
+		if(!identical(names(durations),names(nCollections))){
+			message("Attempting to reorder durations and nCollections so names match")
+			nCollections<-sapply(names(durations), USE.NAMES = FALSE, function(x){ 
+				matches<-names(nCollections)==x
+				if(sum(matches)==1){
+					nCollections[matches]
+				}else{
+					stop("Name matches between durations and nCollections are not one-to-one")
+					}
+				})
+			if(is.list(nCollections)){
+				stop("Multiple matches of names on durations to names on nCollections")
+				}
+			if(length(durations)!=length(nCollections)){
+				stop("durations and nCollections do not contain the same set of taxa, based on input names")
+				}
+			if(!identical(names(durations),names(nCollections))){
+				stop("names still not matching after resorting")
+				}
+			}
 		}
 	if(is.null(durations) | is.null(nCollections)){
 		stop("durations and nCollections have to be both supplied, if one is given")}
