@@ -26,29 +26,29 @@
 #' and ape-derived functions. If FALSE, none of this post-processing is done and users should beware, as such trees can
 #' lead to hard-crashes of R.
 
-#' @param method Controls which algorithm is used for calculating the taxon-tree: either \code{method = "parentChild"}
+#' @param method Controls which algorithm is used for calculating the taxon-tree: either \code{method =} \code{"parentChild"}
 #' (the default option) which converts the listed binary parent-child taxon relationships from the input PBDB data,
 #' or \code{method = "Linnean"}, which converts a taxon-tree by creating a table of the Linnean
 #' taxonomic assignments (family, order, etc), which are provided when
 #' option 'show=phylo' is used in PBDB API calls.
 
 #' @param tipSet This argument only impacts analyses where the argument
-#' \code{method = "parentChild"} is also used. This \code{tipSet} controls
+#' \code{method =} \code{"parentChild"} is also used. This \code{tipSet} controls
 #' which taxa are selected as tip taxa for the
-#' output tree. The default \code{tipSet = "nonParents"} selects all child taxa which
+#' output tree. The default \code{tipSet =} \code{"nonParents"} selects all child taxa which
 #' are not listed as parents in \code{parentChild}. Alternatively, \code{tipSet = "all"}
 #' will add a tip to every internal node with the parent-taxon name encapsulated in
 #' parentheses.
 
-#' @param solveMissing Under \code{method = "parentChild"}, what should \code{makePBDBtaxonTree} do about
+#' @param solveMissing Under \code{method =} \code{"parentChild"}, what should \code{makePBDBtaxonTree} do about
 #' multiple 'floating' parent taxa, listed without their own parent taxon information in the input
 #'  dataset under \code{data}? Each of these is essentially a separate root taxon, for a different set
 #'  of parent-child relationships, and thus poses a problem as far as returning a single phylogeny is
 #'  concerned. If \code{solveMissing = NULL} (the default), nothing is done and the operation halts with
 #'  an error, reporting the identity of these taxa. Two alternative solutions are offered: first,
-#'  \code{solveMissing = "mergeRoots"} will combine these disparate potential roots and link them to an
+#'  \code{solveMissing =} \code{"mergeRoots"} will combine these disparate potential roots and link them to an
 #'  artificially-constructed pseudo-root, which at least allows for visualization of the taxonomic
-#'  structure in a limited dataset. Secondly, \code{solveMissing = "queryPBDB"} queries the Paleobiology
+#'  structure in a limited dataset. Secondly, \code{solveMissing =} \code{"queryPBDB"} queries the Paleobiology
 #'  Database repeatedly via the API for information on parent taxa of the 'floating' parents, and continues
 #'  within a \code{while()} loop until only one such unassigned parent taxon remains. This latter option may
 #'  talk a long time or never finish, depending on the linearity and taxonomic structures encountered in the
@@ -56,10 +56,16 @@
 #'  mistake, then under this option \code{makePBDBtaxonTree} might never finish. In cases where taxonomy is
 #'  bad due to weird and erroneous taxonomic assignments reported by the PBDB, this routine may search all
 #'  the way back to a very ancient and deep taxon, such as the Eukaryota taxon.
-#' Users should thus use \code{solveMissing="queryPBDB"} only with caution.
+#' Users should thus use \code{solveMissing =} \code{"queryPBDB"} only with caution.
+
+#' @param APIversion Version of the Paleobiology Database API used by \code{makePBDBtaxonTree} when
+#' \code{solveMissing =} \code{"queryPBDB"}. The current default is "1.1", which is the only option available
+#' as of 05/05/2015. In the future, the improved API version "1.2" will be released on the public
+#' PBDB server, which will become the new default for this function, but the option to return to "1.1"
+#' behavior will be retained for .
 
 # @param cleanDuplicate If TRUE (\emph{not} the default), duplicated taxa of a
-# taxonomic rank *not* selected by argument \code{rank}
+# taxonomic rank \emph{not} selected by argument \code{rank}
 # will be removed silently. Only duplicates of the taxonomic rank of interest
 # will actually result in an error message.
 
@@ -157,6 +163,7 @@
 #' }
 #' 
 #' ###################################
+#' \donttest{
 #' 
 #' #let's try time-scaling the graptolite tree
 #' 
@@ -185,6 +192,7 @@
 #' 
 #' #drops a lot of taxa; some of this is due to mispellings, etc
 #' 
+#' }
 #' \dontrun{
 #' 
 #' #make pretty plot with library strap
@@ -199,7 +207,7 @@
 #' @rdname makePBDBtaxonTree
 #' @export
 makePBDBtaxonTree<-function(data,rank,method="parentChild",solveMissing=NULL,
-					tipSet="nonParents",cleanTree=TRUE){		
+					tipSet="nonParents",cleanTree=TRUE,APIversion="1.1"){		
 	# 
 	# library(paleotree);data(graptPBDB);
 	# data<-graptTaxaPBDB; rank="genus"; method="parentChild"; tipSet="nonParents"; cleanTree=TRUE; solveMissing=NULL
@@ -273,7 +281,7 @@ makePBDBtaxonTree<-function(data,rank,method="parentChild",solveMissing=NULL,
 			if(length(floatersNew)>1 & identical(sort(floaters),sort(floatersNew))){
 				if(!is.null(solveMissing)){
 					if(solveMissing=="queryPBDB"){
-						floatData<-queryMissingParents(taxaID=floatersNew)	
+						floatData<-queryMissingParents(taxaID=floatersNew,APIversion=APIversion)	
 						#update taxon names in taxonNameTable
 						whichUpdate<-match(floatData[,"taxon_no"],taxonNameTable[,1])
 						taxonNameTable[whichUpdate[!is.na(whichUpdate)],2]<-floatData[
@@ -400,12 +408,13 @@ translatePBDBtaxa<-function(data){
 	}
 
 #another hidden function
-queryMissingParents<-function(taxaID){
+queryMissingParents<-function(taxaID, APIversion="1.1"){
 	#drop Eukarya, as it won't return if status=senior under 1.1
 	#taxaID<-as.numeric(taxaID[taxaID!="1"])
 	#let's get some taxonomic data
 	floatData<-read.csv(paste0("http://paleobiodb.org/",
-		"data1.1/taxa/list.txt?id=",paste0(taxaID,collapse=","),
+		"data",APIversion,
+		"/taxa/list.txt?id=",paste0(taxaID,collapse=","),
 		"&rel=self&status=senior&vocab=pbdb"),
 		stringsAsFactors=FALSE)
 	if(nrow(floatData)==0){
